@@ -1,5 +1,6 @@
 import os
 import sys
+import time
 from PySide.QtCore import *
 from PySide.QtGui import *
 
@@ -8,6 +9,7 @@ OPTION_CHAR =  ' '
 HOME = os.path.expanduser("~")
 GNGEO_CFG_FILE = HOME + '/.gngeo/gngeorc'
 GNGEOGUI_CFG_FILE = HOME + '/.gngeo-gui/gngeo-gui.cfg'
+GNGEOGUI_LOG_FILE = HOME + '/.gngeo-gui/gngeo-output.log'
 P1buttons = ""
 P2buttons = ""
 BiosPath = ""
@@ -36,7 +38,6 @@ def parse_config(self, filename):
         return options
 
 
-
 class Ui_MainWindow(QWidget):
     def __init__(self):
         QWidget.__init__(self, None)
@@ -59,6 +60,11 @@ class Ui_MainWindow(QWidget):
 	except:
 		QMessageBox.critical(self, "Critical", "Config file '" + GNGEO_CFG_FILE + "' not readable!")
     		sys.exit()
+	global AboutGnGeo
+	VersionGnGeo = self.gui_opts["exec_path"] + "/gngeo --version" 
+	fin,fout = os.popen4(VersionGnGeo)
+	AboutGnGeo = fout.read()
+	AboutGnGeo = "Using " + AboutGnGeo.replace('\n','<br>')
 	# Load config
         self.options = parse_config(self,GNGEO_CFG_FILE)
 	myPaths = [ "rompath", "biospath", "romrcdir" ]
@@ -149,16 +155,57 @@ class Ui_MainWindow(QWidget):
 	QObject.connect(self.pushAboutButton
 		, SIGNAL("clicked()")
 		, self.slotAbout)
+	self.logMsg = QLabel(self)
+      	self.logMsg.setStyleSheet( \
+	"QLabel { background-color: QLinearGradient( x1: 0, y1: 0, x2: 0, y2: 1, \
+         stop: 0 #bbb, stop: 0.1 #999, stop: 0.49 #444, stop: 0.5 #666, stop: 1 #444); \
+         font-size: 20px; font-family: monospace; font-weight: bold;}" \
+      	) 
+	self.logMsg.setGeometry(0, 350, 800, 20)
 
 
     def on_start_clicked(self):
 	gameNbr = self.combo.currentIndex()
 	self.gameFile = self.GameFile[gameNbr]
+	global MyTeller
+	global regel
+
         if self.muteCheckBox.isChecked():
                SOUND_OPT=" --no-sound "
-        else:  SOUND_OPT=" --sound " 
+        else:  SOUND_OPT=" --sound "
+
 	if self.gameFile:
 		QProcess.startDetached(self.gui_opts["exec_path"]+"/gngeo "+SOUND_OPT+self.options["rompath"]+'/'+self.gameFile)
+                time.sleep(0.1)    # Sleep briefly
+		file = open(GNGEOGUI_LOG_FILE,'r')
+                self.MyTeller = 0
+		def follow(thefile):
+			    thefile.seek(0,1)      # Go to the end of the file
+			    while True:
+			         line = thefile.readline()
+			         if not line:
+				     self.MyTeller = self.MyTeller + 1
+			             time.sleep(0.1)    # Sleep briefly
+			             continue
+			         yield line
+
+		loglines = follow(file)
+		for line in loglines:
+		    if '\r' in line:
+			line = line.strip('\n')
+			line = line.replace('\r','\n')
+			lines = line.split('\n')
+			for subline in lines:
+				regel = subline
+				self.logMsg.setText(regel)
+				# Keep the app responsive in this loop
+				QCoreApplication.processEvents()
+			#print >> sys.stderr,line
+		    if (self.MyTeller > 90) or ("Convert" in line):
+			file.close()
+			open(GNGEOGUI_LOG_FILE, 'w').close()
+			break
+
 
     def slotAbout(self):
         a = AboutWindow(self)
@@ -175,11 +222,12 @@ class AboutWindow(QMainWindow):
         self.setAttribute(Qt.WA_Maemo5StackedWindow)
         self.setAttribute(Qt.WA_DeleteOnClose)
         self.label = QLabel(self)
-        AboutTxt = "<h3>Gngeo-gui 0.0.4-1</h3><p>" \
+        AboutTxt = "<h3>Gngeo-gui 0.0.5-1</h3><p>" \
                    "<img src=/opt/usr/share/icons/hicolor/64x64/apps/gngeo_gui.png /><br>" \
                    "GnGeo-gui is a Graphical User Interface for GnGeo<p> " \
                    "GnGeo emulates the NeoGeo gameconsole from SNK &#174;</p>" \
-                   "<p>GnGeo-gui is written in PySide by <i>Arno Dekker<\i>" 
+                   "<p>GnGeo-gui is written in PySide by <i>Arno Dekker</i> 2011<p>"
+	AboutTxt = AboutTxt + AboutGnGeo
         self.label.setText(AboutTxt)
 	self.label.setAlignment(Qt.AlignCenter | Qt.AlignLeft)
       	self.setCentralWidget(self.label)
@@ -284,8 +332,8 @@ class ConfigWindow(QMainWindow):
 		, SIGNAL("clicked()")
 		, self.on_paths_clicked)
 	# Samplerate
-	label = QLabel("<i>snd_rate:</i>", self)
-	label.move(595,145)
+	label = QLabel("<i>sound rate:</i>", self)
+	label.setGeometry(595,145,140,30)
         self.comboSampleRate = QComboBox(self)
 	self.comboSampleRate.setGeometry(QRect(530, 170, 250, 60))
 	Sam_Rates = self.listDefaultFirst("samplerate",['8192','11025','22050','32000','44100','48000'])
