@@ -8,4 +8,4 @@ then
 	echo "exec_path /opt/gngeo/bin" > $CFG_FILE
 fi
 cd /opt/gngeo-gui/
-python gngeo-gui.py
+python gngeo-gui.py > $CFG_DIR/gngeo-output.log
